@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2018 - 2019 Michael Vetter <jubalh@idoru.org>
+ * Copyright (C) 2018 - 2022 Michael Vetter <jubalh@idoru.org>
  *
  * This file is part of Profanity.
  *
@@ -59,6 +59,7 @@
 #define DIR_DATABASE  "database"
 #define DIR_DOWNLOADS "downloads"
 #define DIR_EDITOR    "editor"
+#define DIR_CERTS     "certs"
 
 void files_create_directories(void);
 
@@ -69,4 +70,7 @@ gchar* files_get_account_data_path(const char* const specific_dir, const char* c
 gchar* files_get_log_file(const char* const log_file);
 gchar* files_get_inputrc_file(void);
 
+gchar*
+files_file_in_account_data_path(const char* const specific_dir, const char* const jid, const char* const file_name);
+
 #endif
