@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -265,7 +265,6 @@ prefs_reload(void)
 void
 prefs_load(char* config_file)
 {
-
     if (config_file == NULL) {
         prefs_loc = files_get_config_path(FILE_PROFRC);
     } else {
@@ -1817,6 +1816,9 @@ _get_group(preference_t pref)
     case PREF_TITLEBAR_MUC_TITLE_NAME:
     case PREF_SLASH_GUARD:
     case PREF_COMPOSE_EDITOR:
+    case PREF_OUTGOING_STAMP:
+    case PREF_INCOMING_STAMP:
+    case PREF_MOOD:
         return PREF_GROUP_UI;
     case PREF_STATES:
     case PREF_OUTTYPE:
@@ -1828,6 +1830,7 @@ _get_group(preference_t pref)
     case PREF_NOTIFY_CHAT_TEXT:
     case PREF_NOTIFY_ROOM:
     case PREF_NOTIFY_ROOM_MENTION:
+    case PREF_NOTIFY_ROOM_OFFLINE:
     case PREF_NOTIFY_ROOM_TRIGGER:
     case PREF_NOTIFY_ROOM_CURRENT:
     case PREF_NOTIFY_ROOM_TEXT:
@@ -1879,6 +1882,8 @@ _get_group(preference_t pref)
     case PREF_OMEMO_POLICY:
     case PREF_OMEMO_TRUST_MODE:
         return PREF_GROUP_OMEMO;
+    case PREF_OX_LOG:
+        return PREF_GROUP_OX;
     default:
         return NULL;
     }
@@ -1964,6 +1969,8 @@ _get_key(preference_t pref)
         return "room.trigger";
     case PREF_NOTIFY_ROOM_MENTION:
         return "room.mention";
+    case PREF_NOTIFY_ROOM_OFFLINE:
+        return "room.offline";
     case PREF_NOTIFY_ROOM_CURRENT:
         return "room.current";
     case PREF_NOTIFY_ROOM_TEXT:
@@ -2144,6 +2151,14 @@ _get_key(preference_t pref)
         return "compose.editor";
     case PREF_SILENCE_NON_ROSTER:
         return "silence.incoming.nonroster";
+    case PREF_OUTGOING_STAMP:
+        return "stamp.outgoing";
+    case PREF_INCOMING_STAMP:
+        return "stamp.incoming";
+    case PREF_OX_LOG:
+        return "log";
+    case PREF_MOOD:
+        return "mood";
     default:
         return NULL;
     }
@@ -2195,6 +2210,7 @@ _get_default_boolean(preference_t pref)
     case PREF_INTYPE:
     case PREF_INTYPE_CONSOLE:
     case PREF_NOTIFY_MENTION_WHOLE_WORD:
+    case PREF_MOOD:
         return TRUE;
     default:
         return FALSE;
@@ -2210,12 +2226,10 @@ _get_default_string(preference_t pref)
     case PREF_AUTOAWAY_MODE:
         return "off";
     case PREF_OTR_LOG:
-        return "redact";
+        return "on";
     case PREF_OTR_POLICY:
         return "manual";
     case PREF_STATUSES_CONSOLE:
-    case PREF_STATUSES_CHAT:
-    case PREF_STATUSES_MUC:
         return "all";
     case PREF_ROSTER_BY:
         return "presence";
@@ -2228,6 +2242,8 @@ _get_default_string(preference_t pref)
     case PREF_ROSTER_ROOMS_POS:
         return "last";
     case PREF_ROSTER_ROOMS_BY:
+    case PREF_STATUSES_CHAT:
+    case PREF_STATUSES_MUC:
         return "none";
     case PREF_ROSTER_ROOMS_USE_AS_NAME:
         return "name";
@@ -2254,7 +2270,7 @@ _get_default_string(preference_t pref)
     case PREF_TIME_LASTACTIVITY:
         return "%d/%m/%y %H:%M:%S";
     case PREF_PGP_LOG:
-        return "redact";
+        return "on";
     case PREF_CONSOLE_MUC:
     case PREF_CONSOLE_PRIVATE:
     case PREF_CONSOLE_CHAT:
@@ -2266,7 +2282,7 @@ _get_default_string(preference_t pref)
     case PREF_STATUSBAR_ROOM:
         return "room";
     case PREF_OMEMO_LOG:
-        return "redact";
+        return "on";
     case PREF_OMEMO_POLICY:
         return "automatic";
     case PREF_OMEMO_TRUST_MODE:
@@ -2282,8 +2298,14 @@ _get_default_string(preference_t pref)
         gchar* editor = getenv("EDITOR");
         return editor ? editor : "vim";
     }
+    case PREF_OUTGOING_STAMP:
+        return "me";
+    case PREF_INCOMING_STAMP:
+        return NULL;
     case PREF_URL_SAVE_CMD:
         return NULL; // Default to built-in method.
+    case PREF_OX_LOG:
+        return "on";
     default:
         return NULL;
     }
