@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -184,6 +184,9 @@ theme_exists(const char* const theme_name)
 gboolean
 theme_load(const char* const theme_name, gboolean load_theme_prefs)
 {
+    if (!theme_exists(theme_name))
+        return FALSE;
+
     color_pair_cache_reset();
 
     if (_theme_load_file(theme_name)) {
@@ -406,40 +409,40 @@ _load_preferences(void)
     // with custom set functions
     if (g_key_file_has_key(theme, "ui", "occupants.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "occupants.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_occupants_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_occupants_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "occupants.header.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "occupants.header.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_occupants_header_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_occupants_header_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.header.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.header.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_header_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_header_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.contact.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.contact.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_contact_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_contact_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.resource.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.resource.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_resource_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_resource_char(ch);
             g_free(ch);
         }
     } else {
@@ -448,24 +451,24 @@ _load_preferences(void)
 
     if (g_key_file_has_key(theme, "ui", "roster.rooms.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.rooms.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_room_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_room_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.rooms.private.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.rooms.private.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_room_private_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_room_private_char(ch);
             g_free(ch);
         }
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.private.char", NULL)) {
         gchar* ch = g_key_file_get_string(theme, "ui", "roster.private.char", NULL);
-        if (ch && strlen(ch) > 0) {
-            prefs_set_roster_private_char(ch[0]);
+        if (ch && g_utf8_strlen(ch, 4) == 1) {
+            prefs_set_roster_private_char(ch);
             g_free(ch);
         }
     }
@@ -663,20 +666,21 @@ theme_get_bkgnd(void)
 static void
 _theme_prep_fgnd(char* setting, GString* lookup_str, gboolean* bold)
 {
-    gchar* val = g_key_file_get_string(theme, "colours", setting, NULL);
-    if (!val) {
-        char* def = g_hash_table_lookup(defaults, setting);
-        g_string_append(lookup_str, def);
+    gchar* conf_str = g_key_file_get_string(theme, "colours", setting, NULL);
+    gchar* val = conf_str;
+
+    if (!val)
+        val = g_hash_table_lookup(defaults, setting);
+
+    if (g_str_has_prefix(val, "bold_")) {
+        g_string_append(lookup_str, &val[5]);
+        *bold = TRUE;
     } else {
-        if (g_str_has_prefix(val, "bold_")) {
-            g_string_append(lookup_str, &val[5]);
-            *bold = TRUE;
-        } else {
-            g_string_append(lookup_str, val);
-            *bold = FALSE;
-        }
+        g_string_append(lookup_str, val);
+        *bold = FALSE;
     }
-    g_free(val);
+
+    g_free(conf_str);
 }
 
 char*
