@@ -68,15 +68,9 @@ identity_key_store_new(identity_key_store_t* identity_key_store)
     identity_key_store->public = NULL;
 }
 
-#ifdef HAVE_LIBSIGNAL_LT_2_3_2
-int
-load_session(signal_buffer** record, const signal_protocol_address* address,
-             void* user_data)
-#else
 int
 load_session(signal_buffer** record, signal_buffer** user_record,
              const signal_protocol_address* address, void* user_data)
-#endif
 {
     GHashTable* session_store = (GHashTable*)user_data;
     GHashTable* device_store = NULL;
@@ -124,17 +118,11 @@ get_sub_device_sessions(signal_int_list** sessions, const char* name,
     return SG_SUCCESS;
 }
 
-#ifdef HAVE_LIBSIGNAL_LT_2_3_2
-int
-store_session(const signal_protocol_address* address, uint8_t* record,
-              size_t record_len, void* user_data)
-#else
 int
 store_session(const signal_protocol_address* address,
               uint8_t* record, size_t record_len,
               uint8_t* user_record, size_t user_record_len,
               void* user_data)
-#endif
 {
     GHashTable* session_store = (GHashTable*)user_data;
     GHashTable* device_store = NULL;
@@ -431,7 +419,7 @@ is_trusted_identity(const signal_protocol_address* address, uint8_t* key_data,
     signal_buffer* buffer = signal_buffer_create(key_data, key_len);
     signal_buffer* original = g_hash_table_lookup(trusted, GINT_TO_POINTER(address->device_id));
 
-    if(!original) {
+    if (!original) {
         log_debug("[OMEMO][STORE] original not found %s (%d)", address->name, address->device_id);
     }
     ret = original != NULL && signal_buffer_compare(buffer, original) == 0;
