@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -53,6 +53,7 @@
 #include "profanity.h"
 #include "common.h"
 #include "log.h"
+#include "chatlog.h"
 #include "config/files.h"
 #include "config/tlscerts.h"
 #include "config/accounts.h"
@@ -202,6 +203,11 @@ _init(char* log_level, char* config_file, char* log_file, char* theme_name)
     }
 
     ui_init();
+    if (prof_log_level == PROF_LEVEL_DEBUG) {
+        ProfWin* console = wins_get_console();
+        win_println(console, THEME_DEFAULT, "-", "Debug mode enabled! Logging to: ");
+        win_println(console, THEME_DEFAULT, "-", get_log_file_location());
+    }
     session_init();
     cmd_init();
     log_info("Initialising contact list");
