@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -48,8 +48,13 @@
 #include <curses.h>
 #endif
 
+#ifdef HAVE_QRENCODE
+#include <qrencode.h>
+#endif
+
 #include "common.h"
 #include "log.h"
+#include "config/files.h"
 #include "config/preferences.h"
 #include "config/theme.h"
 #include "command/cmd_defs.h"
@@ -387,6 +392,27 @@ cons_show_incoming_private_message(const char* const nick, const char* const roo
     free(priv_show);
 }
 
+static void
+_cons_welcome_first_start(void)
+{
+    gchar* ident_loc = files_get_data_path(FILE_PROFANITY_IDENTIFIER);
+    if (!g_file_test(ident_loc, G_FILE_TEST_EXISTS)) {
+        ProfWin* console = wins_get_console();
+        win_println(console, THEME_DEFAULT, "-", "This seems to be your first time starting Profanity.");
+        win_println(console, THEME_DEFAULT, "-", "");
+        win_println(console, THEME_DEFAULT, "-", "You can connect to an existing XMPP account via /connect myjid@domain.org.");
+        win_println(console, THEME_DEFAULT, "-", "If you plan to connect to this XMPP account regularly we suggest you set up an account:");
+        win_println(console, THEME_DEFAULT, "-", "/account add myaccount");
+        win_println(console, THEME_DEFAULT, "-", "/account set myaccount jid myjid@domain.org");
+        win_println(console, THEME_DEFAULT, "-", "See /help account for more details.");
+        win_println(console, THEME_DEFAULT, "-", "");
+        win_println(console, THEME_DEFAULT, "-", "If you want to register a new XMPP account with a server use:");
+        win_println(console, THEME_DEFAULT, "-", "/register myjid myserver.org");
+        win_println(console, THEME_DEFAULT, "-", "");
+    }
+    g_free(ident_loc);
+}
+
 void
 cons_about(void)
 {
@@ -410,7 +436,7 @@ cons_about(void)
     }
 
     win_println(console, THEME_DEFAULT, "-", "Copyright (C) 2012 - 2019 James Booth <boothj5web@gmail.com>.");
-    win_println(console, THEME_DEFAULT, "-", "Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>.");
+    win_println(console, THEME_DEFAULT, "-", "Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>.");
     win_println(console, THEME_DEFAULT, "-", "License GPLv3+: GNU GPL version 3 or later <https://www.gnu.org/licenses/gpl.html>");
     win_println(console, THEME_DEFAULT, "-", "");
     win_println(console, THEME_DEFAULT, "-", "This is free software; you are free to change and redistribute it.");
@@ -423,6 +449,8 @@ cons_about(void)
         cons_check_version(FALSE);
     }
 
+    _cons_welcome_first_start();
+
     pnoutrefresh(console->layout->win, 0, 0, 1, 0, rows - 3, cols - 1);
 
     cons_alert(NULL);
@@ -862,6 +890,55 @@ cons_show_disco_contact_information(GHashTable* addresses)
     }
 }
 
+void
+cons_show_qrcode(const char* const text)
+{
+#ifdef HAVE_QRENCODE
+    static const size_t ZOOM_SIZE = 10;
+    QRcode* qrcode = QRcode_encodeString(text, 0, QR_ECLEVEL_L, QR_MODE_8, 1);
+
+    int width = (qrcode->width * ZOOM_SIZE);
+    unsigned char* data = qrcode->data;
+
+    ProfWin* console = wins_get_console();
+
+    char* buf = calloc((width * 4) + 1, 1);
+    char* pad = calloc((width * 4) + 5, 1);
+
+    if (!buf || !pad) {
+        free(pad);
+        free(buf);
+        return;
+    }
+
+    for (int i = 0; i < width + 2 * ZOOM_SIZE; i += ZOOM_SIZE) {
+        strcat(pad, "\u2588\u2588");
+    }
+
+    win_println(console, THEME_DEFAULT, "", pad);
+    for (size_t y = 0; y < width; y += ZOOM_SIZE) {
+        for (size_t x = 0; x < width; x += ZOOM_SIZE) {
+            strcat(buf, !(*data & 1) ? "\u2588\u2588" : "\u2800\u2800");
+
+            data++;
+        }
+
+        // The extra squares are for padding, so that the QR code doesn't
+        // "blend in" with the rest of the terminal window.
+        win_println(console, THEME_DEFAULT, "", "\u2588\u2588%s\u2588\u2588", buf);
+        buf[0] = '\0';
+    }
+    win_println(console, THEME_DEFAULT, "", "%s", pad);
+
+    free(pad);
+    free(buf);
+
+    QRcode_free(qrcode);
+#else
+    cons_show("This version of Profanity has not been built with libqrencode");
+#endif
+}
+
 void
 cons_show_status(const char* const barejid)
 {
@@ -1680,6 +1757,7 @@ cons_show_ui_prefs(void)
     cons_inpblock_setting();
     cons_titlebar_setting();
     cons_statusbar_setting();
+    cons_mood_setting();
 
     cons_alert(NULL);
 }
@@ -1717,6 +1795,11 @@ cons_notify_setting(void)
     else
         cons_show("Room mention (/notify room)         : OFF");
 
+    if (prefs_get_boolean(PREF_NOTIFY_ROOM_OFFLINE))
+        cons_show("Room offline messages (/notify room): ON");
+    else
+        cons_show("Room offline messages (/notify room): OFF");
+
     if (prefs_get_boolean(PREF_NOTIFY_MENTION_CASE_SENSITIVE))
         cons_show("Room mention case (/notify room)    : Case sensitive");
     else
@@ -1959,6 +2042,10 @@ cons_log_setting(void)
         cons_show("Shared log (/log shared)    : ON");
     else
         cons_show("Shared log (/log shared)    : OFF");
+
+    log_level_t filter = log_get_filter();
+    const gchar* level = log_string_from_level(filter);
+    cons_show("Log level (/log level)      : %s", level);
 }
 
 void
@@ -2309,6 +2396,29 @@ cons_show_omemo_prefs(void)
     cons_alert(NULL);
 }
 
+void
+cons_show_ox_prefs(void)
+{
+    cons_show("OX preferences:");
+    cons_show("");
+
+    char* log_value = prefs_get_string(PREF_OX_LOG);
+    if (strcmp(log_value, "on") == 0) {
+        cons_show("OX logging (/ox log)   : ON");
+    } else if (strcmp(log_value, "off") == 0) {
+        cons_show("OX logging (/ox log)   : OFF");
+    } else {
+        cons_show("OX logging (/ox log)   : Redacted");
+    }
+    g_free(log_value);
+
+    char* ch = prefs_get_ox_char();
+    cons_show("OX char (/ox char)     : %s", ch);
+    free(ch);
+
+    cons_alert(NULL);
+}
+
 void
 cons_show_themes(GSList* themes)
 {
@@ -2385,6 +2495,8 @@ cons_prefs(void)
     cons_show("");
     cons_show_omemo_prefs();
     cons_show("");
+    cons_show_ox_prefs();
+    cons_show("");
 
     cons_alert(NULL);
 }
@@ -2864,3 +2976,13 @@ cons_remove_alert(ProfWin* window)
     g_list_free_full(item, g_free);
     free(win_name);
 }
+
+void
+cons_mood_setting(void)
+{
+    if (prefs_get_boolean(PREF_MOOD)) {
+        cons_show("Display user mood (/mood)                 : ON");
+    } else {
+        cons_show("Display user mood (/mood)                 : OFF");
+    }
+}
