@@ -3,7 +3,7 @@
  * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 - 2021 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2022 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -46,8 +46,8 @@
 static void
 _occuptantswin_occupant(ProfLayoutSplit* layout, GList* item, gboolean showjid, gboolean isoffline)
 {
-    int colour = 0;                                     //init to workaround compiler warning
-    theme_item_t presence_colour = THEME_ROSTER_ONLINE; //init to workaround compiler warning
+    int colour = 0;                                     // init to workaround compiler warning
+    theme_item_t presence_colour = THEME_ROSTER_ONLINE; // init to workaround compiler warning
     Occupant* occupant = item->data;
 
     if (isoffline) {
@@ -77,9 +77,10 @@ _occuptantswin_occupant(ProfLayoutSplit* layout, GList* item, gboolean showjid,
 
     GString* msg = g_string_new(spaces->str);
 
-    char ch = prefs_get_occupants_char();
+    char* ch = prefs_get_occupants_char();
     if (ch) {
-        g_string_append_printf(msg, "%c", ch);
+        g_string_append_printf(msg, "%s", ch);
+        free(ch);
     }
 
     gboolean wrap = prefs_get_boolean(PREF_OCCUPANTS_WRAP);
@@ -130,9 +131,10 @@ occupantswin_occupants(const char* const roomjid)
 
             GString* prefix = g_string_new(" ");
 
-            char ch = prefs_get_occupants_header_char();
+            char* ch = prefs_get_occupants_header_char();
             if (ch) {
-                g_string_append_printf(prefix, "%c", ch);
+                g_string_append_printf(prefix, "%s", ch);
+                free(ch);
             }
 
             if (prefs_get_boolean(PREF_MUC_PRIVILEGES)) {
