@@ -102,5 +102,7 @@ void win_close_reset_search_attempts(void);
 
 void wins_add_urls_ac(const ProfWin* const win, const ProfMessage* const message);
 char* wins_get_url(const char* const search_str, gboolean previous, void* context);
+void wins_add_quotes_ac(const ProfWin* const win, const char* const message);
+char* wins_get_quote(const char* const search_str, gboolean previous, void* context);
 
 #endif
