@@ -41,13 +41,7 @@
 #include <string.h>
 #include <glib.h>
 
-#ifdef HAVE_LIBMESODE
-#include <mesode.h>
-#endif
-
-#ifdef HAVE_LIBSTROPHE
 #include <strophe.h>
-#endif
 
 #include "common.h"
 #include "log.h"
