@@ -46,6 +46,8 @@ void connection_check_events(void);
 
 jabber_conn_status_t connection_connect(const char* const fulljid, const char* const passwd, const char* const altdomain, int port,
                                         const char* const tls_policy, const char* const auth_policy);
+jabber_conn_status_t connection_register(const char* const altdomain, int port, const char* const tls_policy,
+                                         const char* const username, const char* const password);
 void connection_disconnect(void);
 void connection_set_disconnected(void);
 
