@@ -98,7 +98,7 @@ static char* saved_status;
 
 static void _session_reconnect(void);
 
-static void _session_free_saved_account(void);
+static void _session_free_internals(void);
 static void _session_free_saved_details(void);
 
 void
@@ -117,8 +117,7 @@ session_connect_with_account(const ProfAccount* const account)
 
     log_info("Connecting using account: %s", account->name);
 
-    _session_free_saved_account();
-    _session_free_saved_details();
+    _session_free_internals();
 
     // save account name and password for reconnect
     saved_account.name = strdup(account->name);
@@ -152,8 +151,7 @@ session_connect_with_details(const char* const jid, const char* const passwd, co
     assert(jid != NULL);
     assert(passwd != NULL);
 
-    _session_free_saved_account();
-    _session_free_saved_details();
+    _session_free_internals();
 
     // save details for reconnect, remember name for account creating on success
     saved_details.name = strdup(jid);
@@ -240,8 +238,7 @@ session_disconnect(void)
 void
 session_shutdown(void)
 {
-    _session_free_saved_account();
-    _session_free_saved_details();
+    _session_free_internals();
 
     chat_sessions_clear();
     presence_clear_sub_requests();
@@ -261,6 +258,8 @@ session_process_events(void)
     switch (conn_status) {
     case JABBER_CONNECTED:
     case JABBER_CONNECTING:
+    case JABBER_RAW_CONNECTED:
+    case JABBER_RAW_CONNECTING:
     case JABBER_DISCONNECTING:
         connection_check_events();
         break;
@@ -273,6 +272,9 @@ session_process_events(void)
             }
         }
         break;
+    case JABBER_RECONNECT:
+        _session_reconnect();
+        break;
     default:
         break;
     }
@@ -284,6 +286,40 @@ session_get_account_name(void)
     return saved_account.name;
 }
 
+static gboolean
+_receive_mood(xmpp_stanza_t* const stanza, void* const userdata)
+{
+    if (!prefs_get_boolean(PREF_MOOD)) {
+        return TRUE;
+    }
+
+    const char* from = xmpp_stanza_get_from(stanza);
+    xmpp_stanza_t* event = xmpp_stanza_get_child_by_name_and_ns(stanza, STANZA_NAME_EVENT, STANZA_NS_PUBSUB_EVENT);
+    if (event) {
+        xmpp_stanza_t* items = xmpp_stanza_get_child_by_name(event, STANZA_NAME_ITEMS);
+        if (items) {
+            xmpp_stanza_t* item = xmpp_stanza_get_child_by_name(items, STANZA_NAME_ITEM);
+            if (item) {
+                xmpp_stanza_t* mood = xmpp_stanza_get_child_by_name_and_ns(item, STANZA_NAME_MOOD, STANZA_NS_MOOD);
+                if (mood) {
+                    xmpp_stanza_t* c = xmpp_stanza_get_children(mood);
+                    if (c) {
+                        const char* m = xmpp_stanza_get_name(c);
+                        xmpp_stanza_t* t = xmpp_stanza_get_child_by_name(mood, STANZA_NAME_TEXT);
+                        if (t) {
+                            const char* text = xmpp_stanza_get_text(t);
+                            cons_show("Mood from %s %s (%s)", from, m, text);
+                        } else {
+                            cons_show("Mood from %s %s", from, m);
+                        }
+                    }
+                }
+            }
+        }
+    }
+    return TRUE;
+}
+
 void
 session_login_success(gboolean secured)
 {
@@ -328,6 +364,11 @@ session_login_success(gboolean secured)
         g_timer_destroy(reconnect_timer);
         reconnect_timer = NULL;
     }
+
+    message_pubsub_event_handler_add(STANZA_NS_MOOD, _receive_mood, NULL, NULL);
+    if (prefs_get_boolean(PREF_MOOD)) {
+        caps_add_feature(STANZA_NS_MOOD_NOTIFY);
+    }
 }
 
 void
@@ -336,8 +377,7 @@ session_login_failed(void)
     if (reconnect_timer == NULL) {
         log_debug("Connection handler: No reconnect timer");
         sv_ev_failed_login();
-        _session_free_saved_account();
-        _session_free_saved_details();
+        _session_free_internals();
     } else {
         log_debug("Connection handler: Restarting reconnect timer");
         if (prefs_get_reconnect() != 0) {
@@ -359,8 +399,7 @@ session_lost_connection(void)
         assert(reconnect_timer == NULL);
         reconnect_timer = g_timer_new();
     } else {
-        _session_free_saved_account();
-        _session_free_saved_details();
+        _session_free_internals();
     }
 }
 
@@ -502,6 +541,22 @@ session_check_autoaway(void)
     g_free(mode);
 }
 
+static struct
+{
+    gchar* altdomain;
+    unsigned short altport;
+} reconnect;
+
+/* This takes ownership of `altdomain`, i.e. the caller must not
+ * free the value after calling this function.
+ */
+void
+session_reconnect(gchar* altdomain, unsigned short altport)
+{
+    reconnect.altdomain = altdomain;
+    reconnect.altport = altport;
+}
+
 static void
 _session_reconnect(void)
 {
@@ -518,19 +573,31 @@ _session_reconnect(void)
     } else {
         jid = strdup(account->jid);
     }
+    const char* server;
+    unsigned short port;
+    if (reconnect.altdomain) {
+        server = reconnect.altdomain;
+        port = reconnect.altport;
+    } else {
+        server = account->server;
+        port = account->port;
+    }
 
     log_debug("Attempting reconnect with account %s", account->name);
-    connection_connect(jid, saved_account.passwd, account->server, account->port, account->tls_policy, account->auth_policy);
+    connection_connect(jid, saved_account.passwd, server, port, account->tls_policy, account->auth_policy);
     free(jid);
     account_free(account);
-    g_timer_start(reconnect_timer);
+    if (reconnect_timer)
+        g_timer_start(reconnect_timer);
 }
 
 static void
-_session_free_saved_account(void)
+_session_free_internals(void)
 {
     FREE_SET_NULL(saved_account.name);
     FREE_SET_NULL(saved_account.passwd);
+    GFREE_SET_NULL(reconnect.altdomain);
+    _session_free_saved_details();
 }
 
 static void
