@@ -98,21 +98,3 @@ p_gpg_format_fp_str(char* fp)
 {
     return NULL;
 }
-
-gboolean
-ox_is_private_key_available(const char* const barejid)
-{
-    return FALSE;
-}
-
-gboolean
-ox_is_public_key_available(const char* const barejid)
-{
-    return FALSE;
-}
-
-GHashTable*
-ox_gpg_public_keys(void)
-{
-    return NULL;
-}
