@@ -790,6 +790,10 @@ void
 cons_show_omemo_prefs(void)
 {
 }
+void
+cons_show_ox_prefs(void)
+{
+}
 
 void
 cons_show_account(ProfAccount* account)
@@ -919,27 +923,38 @@ void
 cons_show_disco_items(GSList* items, const char* const jid)
 {
 }
+
 void
 cons_show_disco_info(const char* from, GSList* identities, GSList* features)
 {
 }
+
+void
+cons_show_qrcode(const char* const text)
+{
+}
+
 void
 cons_show_room_invite(const char* const invitor, const char* const room,
                       const char* const reason)
 {
 }
+
 void
 cons_check_version(gboolean not_available_msg)
 {
 }
+
 void
 cons_show_typing(const char* const barejid)
 {
 }
+
 void
 cons_show_incoming_room_message(const char* const nick, const char* const room, const int win_index, gboolean mention, GList* triggers, int unread, ProfWin* const window)
 {
 }
+
 void
 cons_show_incoming_message(const char* const short_from, const int win_index, int unread, ProfWin* const window)
 {
@@ -1134,6 +1149,11 @@ cons_silence_setting(void)
 {
 }
 
+void
+cons_mood_setting(void)
+{
+}
+
 void
 cons_show_bookmarks_ignore(gchar** list, gsize len)
 {
